@@ -2,21 +2,24 @@
 the key difference being that nested parsing treats the text as Markdown not rST.
 """
 import os
-from pathlib import Path
 import re
 import sys
-from typing import List, Optional, Tuple, Type
+from pathlib import Path
+from typing import TYPE_CHECKING, List, Optional, Tuple, Type
 
 from docutils import nodes
-from docutils.parsers.rst import Directive, DirectiveError, Parser as RSTParser
+from docutils.parsers.rst import Directive, DirectiveError
+from docutils.parsers.rst import Parser as RSTParser
 from docutils.parsers.rst.directives.misc import Include
-from docutils.parsers.rst.languages import get_language
-from docutils.parsers.rst.states import Inliner, RSTStateMachine, Body
+from docutils.parsers.rst.states import Body, Inliner, RSTStateMachine
 from docutils.statemachine import StringList
 from docutils.utils import unescape
 
 from .parse_directives import parse_directive_text
 
+if TYPE_CHECKING:
+    from .docutils_renderer import DocutilsRenderer
+
 
 class MockingError(Exception):
     """An exception to signal an error during mocking of docutils components."""
@@ -28,7 +31,7 @@ class MockInliner:
     This is parsed to role functions.
     """
 
-    def __init__(self, renderer, lineno: int):
+    def __init__(self, renderer: "DocutilsRenderer", lineno: int):
         self._renderer = renderer
         self.document = renderer.document
         self.reporter = renderer.document.reporter
@@ -37,10 +40,12 @@ class MockInliner:
             # but I can't see how that would work in RST?
             self.reporter.get_source_and_line = lambda l: (self.document["source"], l)
         self.parent = renderer.current_node
-        self.language = renderer.language_module
+        self.language = renderer.language_module_rst
         self.rfc_url = "rfc%d.html"
 
-    def problematic(self, text: str, rawsource: str, message: nodes.system_message):
+    def problematic(
+        self, text: str, rawsource: str, message: nodes.system_message
+    ) -> nodes.problematic:
         msgid = self.document.set_id(message, self.parent)
         problematic = nodes.problematic(rawsource, rawsource, refid=msgid)
         prbid = self.document.set_id(problematic)
@@ -49,7 +54,7 @@ class MockInliner:
 
     # TODO add parse method
 
-    def __getattr__(self, name):
+    def __getattr__(self, name: str):
         """This method is only be called if the attribute requested has not
         been defined. Defined attributes will not be overridden.
         """
@@ -71,7 +76,12 @@ class MockState:
     rather than RST.
     """
 
-    def __init__(self, renderer, state_machine: "MockStateMachine", lineno: int):
+    def __init__(
+        self,
+        renderer: "DocutilsRenderer",
+        state_machine: "MockStateMachine",
+        lineno: int,
+    ):
         self._renderer = renderer
         self._lineno = lineno
         self.document = renderer.document
@@ -81,8 +91,8 @@ class MockState:
         class Struct:
             document = self.document
             reporter = self.document.reporter
-            language = self.document.settings.language_code
-            title_styles = []
+            language = renderer.language_module_rst
+            title_styles: List[str] = []
             section_level = max(renderer._level_to_elem)
             section_bubble_up_kludge = False
             inliner = MockInliner(renderer, lineno)
@@ -121,7 +131,8 @@ class MockState:
         match_titles: bool = False,
         state_machine_class=None,
         state_machine_kwargs=None,
-    ):
+    ) -> None:
+        """Perform a nested parse of the input block, with ``node`` as the parent."""
         current_match_titles = self.state_machine.match_titles
         self.state_machine.match_titles = match_titles
         with self._renderer.current_node_context(node):
@@ -130,7 +141,7 @@ class MockState:
             )
         self.state_machine.match_titles = current_match_titles
 
-    def parse_target(self, block, block_text, lineno):
+    def parse_target(self, block, block_text, lineno: int):
         """
         Taken from https://github.com/docutils-mirror/docutils/blob/e88c5fb08d5cdfa8b4ac1020dd6f7177778d5990/docutils/parsers/rst/states.py#L1927  # noqa: E501
         """
@@ -143,9 +154,16 @@ class MockState:
         reference = "".join(["".join(line.split()) for line in block])
         return "refuri", unescape(reference)
 
-    def inline_text(self, text: str, lineno: int):
+    def inline_text(
+        self, text: str, lineno: int
+    ) -> Tuple[List[nodes.Element], List[nodes.Element]]:
+        """Parse text with only inline rules.
+
+        :return: (list of nodes, list of messages)
+
+        """
         # TODO return messages?
-        messages = []
+        messages: List[nodes.Element] = []
         paragraph = nodes.paragraph("")
 
         tokens = self._renderer.md.parseInline(text, self._renderer.env)
@@ -170,7 +188,7 @@ class MockState:
     # U+2014 is an em-dash:
     attribution_pattern = re.compile("^((?:---?(?!-)|\u2014) *)(.+)")
 
-    def block_quote(self, lines: List[str], line_offset: int):
+    def block_quote(self, lines: List[str], line_offset: int) -> List[nodes.Element]:
         """Parse a block quote, which is a block of text,
         followed by an (optional) attribution.
 
@@ -214,7 +232,7 @@ class MockState:
         # parse attribution
         if attribution_lines:
             attribution_text = "\n".join(attribution_lines)
-            lineno = self._lineno + line_offset + attribution_line_offset
+            lineno = self._lineno + line_offset + (attribution_line_offset or 0)
             textnodes, messages = self.inline_text(attribution_text, lineno)
             attribution = nodes.attribution(attribution_text, "", *textnodes)
             (
@@ -225,22 +243,27 @@ class MockState:
             elements += messages
         return elements
 
-    def build_table(self, tabledata, tableline, stub_columns=0, widths=None):
+    def build_table(self, tabledata, tableline, stub_columns: int = 0, widths=None):
         return Body.build_table(self, tabledata, tableline, stub_columns, widths)
 
     def build_table_row(self, rowdata, tableline):
         return Body.build_table_row(self, rowdata, tableline)
 
-    def __getattr__(self, name):
+    def __getattr__(self, name: str):
         """This method is only be called if the attribute requested has not
         been defined. Defined attributes will not be overridden.
         """
+        cls = type(self).__name__
         if hasattr(Body, name):
-            msg = "{cls} has not yet implemented attribute '{name}'".format(
-                cls=type(self).__name__, name=name
+            msg = (
+                f"{cls} has not yet implemented attribute '{name}'. "
+                "You can parse RST directly via the `{eval-rst}` directive: "
+                "https://myst-parser.readthedocs.io/en/latest/using/syntax.html#how-directives-parse-content"  # noqa: E501
             )
-            raise MockingError(msg).with_traceback(sys.exc_info()[2])
-        msg = "{cls} has no attribute {name}".format(cls=type(self).__name__, name=name)
+        else:
+            # The requested `name` is not a docutils Body element
+            # (such as "footnote", "block_quote", "paragraph", …)
+            msg = f"{cls} has no attribute '{name}'"
         raise MockingError(msg).with_traceback(sys.exc_info()[2])
 
 
@@ -250,14 +273,14 @@ class MockStateMachine:
     This is parsed to the `Directives.run()` method.
     """
 
-    def __init__(self, renderer, lineno: int):
+    def __init__(self, renderer: "DocutilsRenderer", lineno: int):
         self._renderer = renderer
         self._lineno = lineno
         self.document = renderer.document
-        self.language = get_language(renderer.language_module)
+        self.language = renderer.language_module_rst
         self.reporter = self.document.reporter
-        self.node = renderer.current_node
-        self.match_titles = True
+        self.node: nodes.Element = renderer.current_node
+        self.match_titles: bool = True
 
     def get_source(self, lineno: Optional[int] = None):
         """Return document source path."""
@@ -267,7 +290,7 @@ class MockStateMachine:
         """Return (source path, line) tuple for current or given line number."""
         return self.document["source"], lineno or self._lineno
 
-    def __getattr__(self, name):
+    def __getattr__(self, name: str):
         """This method is only be called if the attribute requested has not
         been defined. Defined attributes will not be overridden.
         """
@@ -290,13 +313,13 @@ class MockIncludeDirective:
 
     def __init__(
         self,
-        renderer,
+        renderer: "DocutilsRenderer",
         name: str,
         klass: Include,
         arguments: list,
         options: dict,
         body: List[str],
-        token,
+        lineno: int,
     ):
         self.renderer = renderer
         self.document = renderer.document
@@ -305,10 +328,9 @@ class MockIncludeDirective:
         self.arguments = arguments
         self.options = options
         self.body = body
-        self.lineno = token.map[0]
-        self.token = token
+        self.lineno = lineno
 
-    def run(self):
+    def run(self) -> List[nodes.Element]:
 
         from docutils.parsers.rst.directives.body import CodeBlock, NumberLines
 
@@ -443,7 +465,7 @@ class MockIncludeDirective:
                 del self.renderer.reporter.get_source_and_line
         return []
 
-    def add_name(self, node):
+    def add_name(self, node: nodes.Element):
         """Append self.options['name'] to node['names'] if it exists.
 
         Also normalize the name string and register it as explicit target.
